@@ -547,8 +547,8 @@ def main(args=None):
             del_min_size,
             "particles as they were not out of specified size range",
         )
-
-    write_size_distribution_to_disk(picking_results, os.path.join(outdir, "DISTR"))
+    if len(picking_results)>0:
+        write_size_distribution_to_disk(picking_results, os.path.join(outdir, "DISTR"))
     ###############################
     #   Filament Post Processing
     ###############################
@@ -616,6 +616,8 @@ def main(args=None):
                     "of",
                     len(picking_result_with_boxes_subsets),
                 )
+                # in case cryolo gets stuck here, I should try: https://pythonspeed.com/articles/python-multiprocessing/
+
                 enhanced_images = line_enhancer.enhance_images(
                     image_subset, mask_creator, num_cpus
                 )
@@ -1193,7 +1195,7 @@ def do_prediction(
             config = json.load(config_buffer)
 
     cryolo_mode = utils.get_cryolo_mode(size_distr=size_distr, config_input_size=config["model"]["input_size"])
-    if cryolo_mode == "NON-SQUARE":
+    if cryolo_mode == cryolo_mode.NON_SQUARE:
         ar = size_distr[0][0]/size_distr[0][1]
         if ar < 1:
             input_size = [int(config["model"]["input_size"] / ar), config["model"]["input_size"]]
